@@ -357,11 +357,19 @@ public class Logol {
 		 	installPath = installPath.replaceAll("\\\\", "/");
 		 	Treatment.installPath = installPath;
 		 	
-		 	if(suffixTool==1) {
-		 		Treatment.suffixSearchPath=installPath+"/tools/suffixSearch.rb";
-		 	}
-		 	else {
+		 	switch(suffixTool) {
+		 	case 0:
 		 		Treatment.suffixSearchPath=installPath+"/tools/logolSearch.rb";
+		 		break;
+		 	case 1:
+		 		Treatment.suffixSearchPath=installPath+"/tools/suffixSearch.rb";
+		 		break;
+		 	case 2:
+		 		Treatment.suffixSearchPath=installPath+"/tools/cassiopeeSearch.rb";
+		 		break;
+		 	default:
+		 		Treatment.suffixSearchPath=installPath+"/tools/cassiopeeSearch.rb";
+		 		break;
 		 	}
 		 	
 		 	savfile = installPath+System.getProperty(FILESEPARATORPROPERTY)+"prolog"+System.getProperty(FILESEPARATORPROPERTY)+"logol.sav";
@@ -1386,6 +1394,51 @@ private static void clean(Vector<String> jobFiles) {
 			tmpFile = new File(jobFiles.get(i)+".fasta.index.dna");
 			tmpFile.delete();
 		}
+		switch(Logol.suffixTool) {
+		case 0:
+			tmpFile = new File(jobFiles.get(i)+".fasta.index.sfx");
+			tmpFile.delete();		
+			tmpFile = new File(jobFiles.get(i)+".fasta.index.sfc");
+			if(tmpFile.exists()) {
+			tmpFile.delete();	
+			}
+			break;
+		case 1:
+			tmpFile = new File(jobFiles.get(i)+".fasta.al1");
+			tmpFile.delete();
+			tmpFile = new File(jobFiles.get(i)+".fasta.bck");
+			tmpFile.delete();
+			tmpFile = new File(jobFiles.get(i)+".fasta.bwt");
+			tmpFile.delete();
+			tmpFile = new File(jobFiles.get(i)+".fasta.des");
+			tmpFile.delete();
+			tmpFile = new File(jobFiles.get(i)+".fasta.lcp");
+			tmpFile.delete();
+			tmpFile = new File(jobFiles.get(i)+".fasta.llv");
+			tmpFile.delete();
+			tmpFile = new File(jobFiles.get(i)+".fasta.ois");
+			tmpFile.delete();
+			tmpFile = new File(jobFiles.get(i)+".fasta.prj");
+			tmpFile.delete();
+			tmpFile = new File(jobFiles.get(i)+".fasta.sds");
+			tmpFile.delete();
+			tmpFile = new File(jobFiles.get(i)+".fasta.skp");
+			tmpFile.delete();
+			tmpFile = new File(jobFiles.get(i)+".fasta.sti1");
+			tmpFile.delete();
+			tmpFile = new File(jobFiles.get(i)+".fasta.suf");
+			tmpFile.delete();
+			tmpFile = new File(jobFiles.get(i)+".fasta.tis");
+			tmpFile.delete();
+			break;
+		case 2:
+		default:
+			tmpFile = new File(jobFiles.get(i)+".fasta.cass");
+			tmpFile.delete();
+			tmpFile = new File(jobFiles.get(i)+".fasta.cass.cass.idx");
+			tmpFile.delete();			
+			break;
+		}
 		if(Logol.suffixTool==0) {
 			tmpFile = new File(jobFiles.get(i)+".fasta.index.sfx");
 			tmpFile.delete();		
@@ -1888,11 +1941,24 @@ private static void clean(Vector<String> jobFiles) {
 		data+=Treatment.getMetaControls();	
 		data+="% **************************\n\n";
 		
+		String ruby_path = "";
+		/*
+		try {
+			ruby_path = System.getProperty("ruby_path");
+			if(ruby_path==null) {
+				ruby_path = "";
+			}
+		}
+		catch(Exception e) {
+			// That's fine
+		}
+		*/
+		
 		if(OS.startsWith("win")) {
-			data+=":-assert(logolShell('ruby.exe')).\n";
+			data+=":-assert(logolShell('"+ruby_path+"ruby.exe')).\n";
 		}
 		else {
-			data+=":-assert(logolShell('ruby')).\n";
+			data+=":-assert(logolShell('"+ruby_path+"ruby')).\n";
 		}
 		
 		data+="% ** Main query ************\n";
