@@ -95,7 +95,12 @@ class StreamGobbler implements Runnable {
 	while (true) {
 	String s = br.readLine ();
 	if (s == null) { break; }
-	logger.debug(s);
+	if (s.startsWith("ERROR")) {
+		logger.error(s);
+	}
+	else {
+		logger.debug(s);
+	}
 	}
 
 	is.close ();
