@@ -2302,6 +2302,45 @@ public class GrammarTest {
             }
         }
 
+   	 @Test
+   	 public void testRubyCassiopee() {
+   		 init();
+		
+ 		Vector<String[]> result = new Vector<String[]>();
+ 		result.add(new String[] {"LogolVAR_1","4","6"});
+ 		result.add(new String[] {"LogolVAR_2","7","10"});
+ 		result.add(new String[] {"LogolVAR_3","11","14"});
+ 		 		
+   			
+   			String[] args = new String[] { "-conf",installDir+System.getProperty(FILESEPARATORPROPERTY)+"test"+System.getProperty(FILESEPARATORPROPERTY)+"ruby-cassiopee.properties" , "-g",installDir+System.getProperty(FILESEPARATORPROPERTY)+"test"+System.getProperty(FILESEPARATORPROPERTY)+"variable.logol" , "-s",installDir+System.getProperty(FILESEPARATORPROPERTY)+"test"+System.getProperty(FILESEPARATORPROPERTY)+"test.fasta", "-max"," 10", "-all"};
+   			try {
+   				Logol.main(args);
+   			} catch (ConfigurationException e) {
+   				fail(e.getMessage());
+   			} catch (IOException e) {
+   				fail(e.getMessage());
+   			}  catch (InterruptedException e) {
+   				fail(e.getMessage());
+   			} catch (ParseException e) {
+   				fail(e.getMessage());
+   			} catch (GrammarException e) {
+   				fail(e.getMessage());
+   			}
+   			
+
+   			try {
+   				checkResult(result,0);
+   			} catch (ParserConfigurationException e) {
+   				fail(e.getMessage());
+   			} catch (SAXException e) {
+   				fail(e.getMessage());
+   			} catch (IOException e) {
+   				fail(e.getMessage());
+   			} catch (TransformerException e) {
+   				fail(e.getMessage());
+   			}
+   			
+   	 }
 		
         /*
         @Test
