@@ -6,6 +6,7 @@ import org.apache.log4j.Logger;
 import org.irisa.genouest.logol.Constants;
 import org.irisa.genouest.logol.Expression;
 import org.irisa.genouest.logol.GrammarException;
+import org.irisa.genouest.logol.Logol;
 import org.irisa.genouest.logol.LogolVariable;
 import org.irisa.genouest.logol.StringConstraint;
 import org.irisa.genouest.logol.StructConstraint;
@@ -810,8 +811,12 @@ public class Variable extends AbstractVariable{
 				String tmp_err = LogolUtils.getTemporaryVariable();
 				prologSentence+=","+tmp_err+" is "+cost+" + "+distance;
 				//Fix 1378: extension too large for comparison
-				//prologSentence+=",getsuffixmatch_pos('"+Treatment.suffixSearchPath+"','"+filename+".fsa',"+motif+","+tmp_err+",SEQUENCELength ,"+Constants.LOGOLVARBEFORE+varID+",0,_,"+Constants.LOGOLVARAFTER+varID+","+suffixMin+","+suffixMax+","+Constants.LOGOLVARSPACER+varID+")";
-				prologSentence+=",getsuffixmatch_pos('"+Treatment.suffixSearchPath+"','"+filename+".fsa',"+motif+","+tmp_err+","+ Treatment.sequenceLength+" ,"+Constants.LOGOLVARBEFORE+varID+",0,_,_,"+suffixMin+","+suffixMax+","+Constants.LOGOLVARSPACER+varID+")";
+				if(Logol.getSuffixTool() == 0 || Logol.getSuffixTool() == 1) {
+					prologSentence+=",getsuffixmatch_pos('"+Treatment.suffixSearchPath+"','"+filename+".fsa',"+motif+","+tmp_err+","+ Treatment.sequenceLength+" ,"+Constants.LOGOLVARBEFORE+varID+",0,_,_,"+suffixMin+","+suffixMax+","+Constants.LOGOLVARSPACER+varID+")";
+				}
+				else {
+					prologSentence+=",cassiopee_pos('"+Treatment.suffixSearchPath+"','"+filename+".fsa',"+motif+","+cost+","+distance+","+ Treatment.sequenceLength+" ,"+Constants.LOGOLVARBEFORE+varID+",0,_,_,"+suffixMin+","+suffixMax+","+Constants.LOGOLVARSPACER+varID+","+Treatment.dataType+")";
+				}
 				//check distance and cost values with tmp_err, get as res VARINDEL and VARERRORS
 				String lv_matchpos = LogolUtils.getTemporaryVariable();
 				prologSentence+=","+lv_matchpos+" is "+Constants.LOGOLVARBEFORE+varID+" + "+Constants.LOGOLVARSPACER+varID;
@@ -826,9 +831,6 @@ public class Variable extends AbstractVariable{
 				
 				prologSentence+=",isexactwithdistinctgapanderror_pos("+lv_matchpos+","+motif+", "+cost+", "+distance+", "+Constants.LOGOLVARERRORS+varID+", "+Constants.LOGOLVARINDEL+varID+","+Constants.LOGOLVARAFTER+varID+")";
 				
-				//isexactwithdistinctgapanderror_pos(InputPos,[E1 | E2], MaxError, MaxDistance, Errors, DistanceErrors, OutPos)
-				//prologSentence+=",isexactwithdistinctgapanderror_pos("+matchpos+","+motif+", "+cost+", "+distance+", "+Constants.LOGOLVARERRORS+varID+", "+Constants.LOGOLVARINDEL+varID+",_)";
-				//prologSentence+=",isexactwithdistinctgapanderror("+lv_matchlist+","+motif+", "+cost+", "+distance+", "+Constants.LOGOLVARERRORS+varID+", "+Constants.LOGOLVARINDEL+varID+",_)";
 				prologSentence+=","+Constants.LOGOLVARINDEL+varID+">="+mindistance;
 				prologSentence+=","+Constants.LOGOLVARERRORS+varID+">="+mincost;
 			}
@@ -843,8 +845,14 @@ public class Variable extends AbstractVariable{
 				prologSentence+=",percent2int("+motif+","+tmp_mindistance+","+mindistance+")";
 				mindistance = tmp_mindistance;
 				}
+
+				if(Logol.getSuffixTool() == 0 || Logol.getSuffixTool() == 1) {
+					prologSentence+=",getsuffixmatch_pos('"+Treatment.suffixSearchPath+"','"+filename+".fsa',"+motif+","+distance+","+Treatment.sequenceLength+","+Constants.LOGOLVARBEFORE+varID+",0,"+Constants.LOGOLVARINDEL+varID+",_,"+suffixMin+","+suffixMax+","+Constants.LOGOLVARSPACER+varID+")";
+				}
+				else {
+					prologSentence+=",cassiopee_pos('"+Treatment.suffixSearchPath+"','"+filename+".fsa',"+motif+",0,"+distance+","+Treatment.sequenceLength+","+Constants.LOGOLVARBEFORE+varID+",0,"+Constants.LOGOLVARINDEL+varID+",_,"+suffixMin+","+suffixMax+","+Constants.LOGOLVARSPACER+varID+","+Treatment.dataType+")";
+				}				
 				
-				prologSentence+=",getsuffixmatch_pos('"+Treatment.suffixSearchPath+"','"+filename+".fsa',"+motif+","+distance+","+Treatment.sequenceLength+","+Constants.LOGOLVARBEFORE+varID+",0,"+Constants.LOGOLVARINDEL+varID+",_,"+suffixMin+","+suffixMax+","+Constants.LOGOLVARSPACER+varID+")";
 				//TODO check it is distance only
 				String matchpos = LogolUtils.getTemporaryVariable();
 				prologSentence+=","+matchpos+" is "+Constants.LOGOLVARBEFORE+varID+" + "+Constants.LOGOLVARSPACER+varID;
@@ -863,7 +871,13 @@ public class Variable extends AbstractVariable{
 				prologSentence+=",percent2int("+motif+","+tmp_mincost+","+mincost+")";
 				mincost=tmp_mincost;
 				}
-				prologSentence+=",getsuffixmatch_pos('"+Treatment.suffixSearchPath+"','"+filename+".fsa',"+motif+","+cost+","+Treatment.sequenceLength+" ,"+Constants.LOGOLVARBEFORE+varID+",1,"+Constants.LOGOLVARERRORS+varID+","+Constants.LOGOLVARAFTER+varID+","+suffixMin+","+suffixMax+","+Constants.LOGOLVARSPACER+varID+")";				
+				
+				if(Logol.getSuffixTool() == 0 || Logol.getSuffixTool() == 1) {
+					prologSentence+=",getsuffixmatch_pos('"+Treatment.suffixSearchPath+"','"+filename+".fsa',"+motif+","+cost+","+Treatment.sequenceLength+" ,"+Constants.LOGOLVARBEFORE+varID+",1,"+Constants.LOGOLVARERRORS+varID+","+Constants.LOGOLVARAFTER+varID+","+suffixMin+","+suffixMax+","+Constants.LOGOLVARSPACER+varID+")";				
+				}
+				else {
+					prologSentence+=",cassiopee_pos('"+Treatment.suffixSearchPath+"','"+filename+".fsa',"+motif+","+cost+",0,"+Treatment.sequenceLength+" ,"+Constants.LOGOLVARBEFORE+varID+",1,"+Constants.LOGOLVARERRORS+varID+","+Constants.LOGOLVARAFTER+varID+","+suffixMin+","+suffixMax+","+Constants.LOGOLVARSPACER+varID+","+Treatment.dataType+")";					
+				}
 				prologSentence += ","+Constants.LOGOLVARINDEL+varID+"=0";
 				prologSentence+=","+Constants.LOGOLVARERRORS+varID+">="+mincost;			
 			}
@@ -890,13 +904,23 @@ public class Variable extends AbstractVariable{
 					}
 					else {
 						// Basic treatment
-						prologSentence+=",getsuffixmatch_pos('"+Treatment.suffixSearchPath+"','"+filename+".fsa',"+motif+",0,"+Treatment.sequenceLength+" ,"+Constants.LOGOLVARBEFORE+varID+",1,"+Constants.LOGOLVARERRORS+varID+","+Constants.LOGOLVARAFTER+varID+","+suffixMin+","+suffixMax+","+Constants.LOGOLVARSPACER+varID+")";
+						if(Logol.getSuffixTool() == 0 || Logol.getSuffixTool() == 1) {
+							prologSentence+=",getsuffixmatch_pos('"+Treatment.suffixSearchPath+"','"+filename+".fsa',"+motif+",0,"+Treatment.sequenceLength+" ,"+Constants.LOGOLVARBEFORE+varID+",1,"+Constants.LOGOLVARERRORS+varID+","+Constants.LOGOLVARAFTER+varID+","+suffixMin+","+suffixMax+","+Constants.LOGOLVARSPACER+varID+")";
+						}
+						else {
+							prologSentence+=",cassiopee_pos('"+Treatment.suffixSearchPath+"','"+filename+".fsa',"+motif+",0,0,"+Treatment.sequenceLength+" ,"+Constants.LOGOLVARBEFORE+varID+",1,"+Constants.LOGOLVARERRORS+varID+","+Constants.LOGOLVARAFTER+varID+","+suffixMin+","+suffixMax+","+Constants.LOGOLVARSPACER+varID+","+Treatment.dataType+")";
+						}						
 					}
 				prologSentence += ","+Constants.LOGOLVARINDEL+varID+"=0";
 				}
 				else {
 					//If not null, do not set ERRORS parameters, will be set later in myCost function
-					prologSentence+=",getsuffixmatch_pos('"+Treatment.suffixSearchPath+"','"+filename+".fsa',"+motif+",0,"+Treatment.sequenceLength+" ,"+Constants.LOGOLVARBEFORE+varID+",1,_,"+Constants.LOGOLVARAFTER+varID+","+suffixMin+","+suffixMax+","+Constants.LOGOLVARSPACER+varID+")";
+					if(Logol.getSuffixTool() == 0 || Logol.getSuffixTool() == 1) {
+						prologSentence+=",getsuffixmatch_pos('"+Treatment.suffixSearchPath+"','"+filename+".fsa',"+motif+",0,"+Treatment.sequenceLength+" ,"+Constants.LOGOLVARBEFORE+varID+",1,_,"+Constants.LOGOLVARAFTER+varID+","+suffixMin+","+suffixMax+","+Constants.LOGOLVARSPACER+varID+")";
+					}
+					else {
+						prologSentence+=",cassiopee_pos('"+Treatment.suffixSearchPath+"','"+filename+".fsa',"+motif+",0,0,"+Treatment.sequenceLength+" ,"+Constants.LOGOLVARBEFORE+varID+",1,_,"+Constants.LOGOLVARAFTER+varID+","+suffixMin+","+suffixMax+","+Constants.LOGOLVARSPACER+varID+","+Treatment.dataType+")";					}
+					
 				}
 			}
 			
